@@ -36,11 +36,11 @@ var providers = {
 
   
   
-  loadProvider:  async function (addonId, provider, js) {
+  loadProvider:  async function (extension, provider, js) {
     //only load, if not yet loaded and if the provider name does not shadow a fuction inside provider.js
     if (!this.loadedProviders.hasOwnProperty(provider) && !this.hasOwnProperty(provider) && js.startsWith("chrome://")) {
       try {
-        let addon = await AddonManager.getAddonByID(addonId);
+        let addon = await AddonManager.getAddonByID(extension.id);
 
         //load provider subscripts into TbSync
         this[provider] = {};
@@ -51,11 +51,11 @@ var providers = {
         
         this.loadedProviders[provider] = {};
         this.loadedProviders[provider].addon = addon;
-        this.loadedProviders[provider].addonId = addonId;
+        this.loadedProviders[provider].extension = extension;
+        this.loadedProviders[provider].addonId = extension.id;
         this.loadedProviders[provider].version = addon.version.toString();
         this.loadedProviders[provider].createAccountWindow = null;
 
-        this.loadedProviders[provider].bundle = Services.strings.createBundle(this[provider].Base.getStringBundleUrl());
         addon.contributorsURL = this[provider].Base.getContributorsUrl();
 
         // check if provider has its own implementation of folderList
@@ -64,7 +64,7 @@ var providers = {
         //load provider
         await this[provider].Base.load();
 
-        await TbSync.messenger.overlayManager.registerOverlay("chrome://tbsync/content/manager/editAccount.xul?provider=" + provider, this[provider].Base.getEditAccountOverlayUrl(), [{name: "oninject", value: "tbSyncEditAccountOverlay.onload(window, new TbSync.AccountData(tbSyncAccountSettings.accountID));"}]);        
+        await TbSync.messenger.overlayManager.registerOverlay("chrome://tbsync/content/manager/editAccount.xhtml?provider=" + provider, this[provider].Base.getEditAccountOverlayUrl());        
         TbSync.dump("Loaded provider", provider + "::" + this[provider].Base.getProviderName() + " ("+this.loadedProviders[provider].version+")");
         
         // reset all accounts of this provider
@@ -104,16 +104,14 @@ var providers = {
           }
         }
         
-        if (TbSync.lightning.isAvailable()) {
-          for (let calendar of TbSync.lightning.cal.getCalendarManager().getCalendars({})) {
-            let storedProvider = calendar.getProperty("tbSyncProvider");
-            if (provider == storedProvider && calendar.type == "storage" && providerData.getFolders({"target": calendar.id}).length == 0) {
-              let name = calendar.name;
-              calendar.name = TbSync.getString("target.orphaned") + ": " + name;
-              calendar.setProperty("disabled", true);
-              calendar.setProperty("tbSyncProvider", "orphaned");
-              calendar.setProperty("tbSyncAccountID", "");        
-            }
+        for (let calendar of TbSync.lightning.cal.getCalendarManager().getCalendars({})) {
+          let storedProvider = calendar.getProperty("tbSyncProvider");
+          if (provider == storedProvider && calendar.type == "storage" && providerData.getFolders({"target": calendar.id}).length == 0) {
+            let name = calendar.name;
+            calendar.name = TbSync.getString("target.orphaned") + ": " + name;
+            calendar.setProperty("disabled", true);
+            calendar.setProperty("tbSyncProvider", "orphaned");
+            calendar.setProperty("tbSyncAccountID", "");        
           }
         }
         
